summarizeByCondition <- function(allData, metric){
  subjs <- unique(allData$subjID)
  conditions <- sort(unique(allData$precueCondition))
  if (length(conditions)==2){
    summary <- data.frame(ID=vector(length=length(subjs)),
                          reliable=vector(length=length(subjs)),
                          unreliable=vector(length=length(subjs)))} else 
                          {summary <- data.frame(ID=vector(length=length(subjs)),
                                                 none=vector(length=length(subjs)),
                                                 reliable=vector(length=length(subjs)),
                                                 unreliable=vector(length=length(subjs)))}
  for (s in 1:length(subjs)){
    subData <- allData[allData$subjID==subjs[s],]
    condMeans <- vector()
    for (cond in 1:length(conditions)){
      if (metric=='RT'){
        RTs <- subData$RT[subData$correctTrial==1&subData$precueCondition==conditions[cond]]
        zRTs <- (RTs - mean(RTs)) / sd(RTs)
        condMeans[cond] <- mean(RTs[abs(zRTs)<3])
      } else if (metric=='PC'){
        condMeans[cond] <- mean(subData$correctTrial[subData$precueCondition==conditions[cond]])
      } else if (metric=='ASD'){
        if (conditions[cond]=='reliable'|conditions[cond]=='unreliable'){
          condMeans[cond] <- mean(subData$distractorIsAttended[subData$precueCondition==conditions[cond]], na.rm=TRUE)}
        else if (conditions[cond]=='none'){
          condMeans[cond] <- mean(subData$nonTargetIsAttended[subData$precueCondition==conditions[cond]], na.rm=TRUE)/5
        }
      } else if (metric=='FSD'){
        if (conditions[cond]=='reliable'|conditions[cond]=='unreliable'){
          subData$firstSaccToDistractor <- as.numeric(subData$firstSacLocation.category==subData$distractorLocation)
          condMeans[cond] <- mean(subData$firstSaccToDistractor[subData$precueCondition==conditions[cond]], na.rm=TRUE)}
        else if (conditions[cond]=='none'){
          subData$firstSaccToDistractor <- as.numeric(subData$firstSacLocation.category!=subData$targetLocation)
          condMeans[cond] <- mean(subData$firstSaccToDistractor[subData$precueCondition==conditions[cond]], na.rm=TRUE)/5
        }
      }
    }
    summary[s,] <- c(subjs[s],condMeans)}
  return(summary)}

doRepeatedMeasuresANOVA_oneWay <- function(dataSummary){
  # check for missing values
  dataSummary <- dataSummary[!is.na(rowMeans(dataSummary)),]
  data <- data.frame(resp.var=c(dataSummary$none,dataSummary$reliable,dataSummary$unreliable),
                     cond=as.factor(c(rep('none',nrow(dataSummary),each=1),rep('reliable',nrow(dataSummary),each=1),rep('unreliable',nrow(dataSummary),each=1))),
                     ID=as.factor(rep(1:nrow(dataSummary),3)))
  model = aov(formula = resp.var ~ cond + Error(ID/cond), data=data)
  print(summary(model))}

printStats <- function(contrast){
  result <- t.test(contrast)
  print(paste('t(',result$parameter,')=',round(result$statistic,digits=2),', p=',round(result$p.value,digits=4),sep=''))}

plotPosterior <- function(posterior, realVal=0, yLim=c(0,100), color="gray", opacity=.3, xLim=c(0,100)){
  df <- as.data.frame(posterior)
  ci_95 <- quantile(df$posterior, prob=c(0.025, .975))
  ggplot(df, aes(x = posterior)) +
    geom_density(alpha = opacity, fill=color) +
    theme_minimal() + 
    geom_vline(xintercept = realVal, linetype = "dashed", color = "black") +
    geom_vline(xintercept = ci_95[1], linetype = "dotted", color = "black") +
    geom_vline(xintercept = ci_95[2], linetype = "dotted", color = "black") +
    geom_vline(xintercept = 0, color = "black") +
    ylim(yLim) + 
    xlim(xLim) + 
    theme(
      legend.position = "none",
      panel.border = element_rect(colour = "black", fill=NA),
      panel.grid.major = element_blank(),
      panel.grid.minor = element_blank())}
